manager_env

Function manager_env 

pub fn manager_env(
    cache_dir: &Path,
    mappings: &[(&str, &str)],
    getenv: impl Fn(&str) -> Option<String>,
) -> BTreeMap<String, String>
Compute version-specific environment variables for one package manager.

mappings contains (environment variable, directory below <cache>/pkg). A value already present in the process is preserved unless it was set by a previous osdk shell hook, in which case OSDK_ORIG_<key>_SET is present and the managed value may be refreshed safely.