pub struct InstallLocator { /* private fields */ }Expand description
All filesystem locations derived from one validated dynamic install identity.
Implementations
Sourceimpl InstallLocator
impl InstallLocator
pub fn new(dirs: &Dirs, identity: InstallIdentity) -> Result<Self>
pub fn identity(&self) -> &InstallIdentity
pub fn install_root(&self) -> &Path
pub fn legacy_install_root(&self) -> &Path
pub fn legacy_global_install_root(&self) -> Option<&Path>
pub fn lock_path(&self) -> &Path
pub fn scratch_root(&self) -> &Path
Sourcepub fn validates_install_root(&self, root: &Path) -> bool
pub fn validates_install_root(&self, root: &Path) -> bool
Require a discovered manifest to reside at this identity’s canonical fingerprinted root, with no links inside the osdk-managed tree.
Sourcepub fn validates_existing_install_root(&self, root: &Path) -> bool
pub fn validates_existing_install_root(&self, root: &Path) -> bool
Require the canonical identity root to exist entirely as real directories. This is the filesystem trust check for consumers that are about to execute or remove content from an install.
Sourcepub fn is_canonical_install_root(
installs: &Path,
identity: &InstallIdentity,
root: &Path,
) -> Result<bool>
pub fn is_canonical_install_root( installs: &Path, identity: &InstallIdentity, root: &Path, ) -> Result<bool>
Validate a scanned root using only the configured installs directory.