run

Function run 

pub fn run(
    program: &str,
    args: &[&str],
    env: &BTreeMap<String, String>,
    cwd: Option<&Path>,
) -> Result<()>
Run a command to completion, capturing stderr on failure. env overrides are applied on top of the inherited environment.