Version request / resolution types shared across backends.
Modules
- resolver
- Active-version resolution for a working directory.
Structs
- Tool
Request - A parsed
tool@specrequest with optional backend-specific options (e.g. java distribution, rust profile). - Tool
Version - A resolved concrete version, ready to install/activate.
- Version
Info - Metadata about a single installable version.
Enums
- Version
Spec - What the user asked for, before resolution against remote versions.
Functions
- select_
version - Select the best matching version string from a candidate list for a spec.
- select_
version_ with_ prerelease